package ru.crystals.pos.api.card;

import ru.crystals.pos.spi.receipt.BonusBalance;
import ru.crystals.pos.spi.receipt.Card;
import ru.crystals.pos.spi.receipt.CardHolder;
import ru.crystals.pos.spi.receipt.CardStatus;
import ru.crystals.pos.spi.receipt.CardType;

/**
 * Сущность описывающая карту/купон.
 */
public class CardEntity implements Card {

    private String id;

    private String cardNumber;

    private CardType cardType;

    private CardHolder cardHolder;

    private String processingId;

    private BonusBalance bonusBalance;

    private CardStatus cardStatus = CardStatus.ACTIVE;

    public CardEntity() {
        super();
    }

    public CardEntity(String cardNumber, String processingId) {
        this();
        setCardNumber(cardNumber);
        setProcessingId(processingId);
    }
    
    /**
     * Конструктор
     * @param cardNumber номер карты
     * @param type тип карты
     * @param processingId идентификатор процессинга
     * @see CardType
     */
    public CardEntity(String cardNumber, CardType type, String processingId) {
        this(cardNumber, processingId);
        setCardType(type);
    }

    /* (non-Javadoc)
     * @see ru.crystals.pos.api.card.Card#getId()
     */
    @Override
    public String getId() {
        return id;
    }
    
    /**
     * Установить уникальный идентификатор данной карты.
     * 
     * @see #getId()
     * @param id идентификатор карты 
     */
    public void setId(String id) {
        this.id = id;
    }
    
    /* (non-Javadoc)
     * @see ru.crystals.pos.api.card.Card#getCardNumber()
     */
    @Override
    public String getCardNumber() {
        return cardNumber;
    }
    
    /**
     * Установить номер карты
     *
     * @param cardNumber номер карты
     */
    public void setCardNumber(String cardNumber) {
        this.cardNumber = cardNumber;
        if (this.id == null) {
            this.id = cardNumber;
        }
    }

    /* (non-Javadoc)
     * @see ru.crystals.pos.api.card.Card#geCardType()
     */
    @Override
    public CardType getCardType() {
        return cardType;
    }
    
    /**
     * Установить тип карты
     * @param cardType тип карты
     * @see CardType
     */
    public void setCardType(CardType cardType) {
        this.cardType = cardType;
    }

    /* (non-Javadoc)
     * @see ru.crystals.pos.api.card.Card#getCardHolder()
     */
    @Override
    public CardHolder getCardHolder() {
        return cardHolder;
    }

    /**
     * Установить владельца карты
     * 
     * @param holder владелец карты
     * @see CardHolderEntity
     */
    public void setCardHolder(CardHolder holder) {
        this.cardHolder = holder;
    }

    /* (non-Javadoc)
     * @see ru.crystals.pos.api.card.Card#getProcessingId()
     */
    @Override
    public String getProcessingId() {
        return processingId;
    }

    /**
     * Установить идентификатор процессинга, которому "принадлежит" карта
     * 
     * @param processingId {@code null}, если идентификатор процессинга не известен
     */
    public void setProcessingId(String processingId) {
        this.processingId = processingId;
    }
    
    /* (non-Javadoc)
     * @see ru.crystals.pos.api.card.Card#getBonusBalance()
     */
    @Override
    public BonusBalance getBonusBalance() {
        return bonusBalance;
    }

    /**
     * Установить бонусный баланс карты
     * 
     * @param bonusBalance бонусный баланс карты
     * @see BonusBalanceEntity
     */
    public void setBonusBalance(BonusBalance bonusBalance) {
        this.bonusBalance = bonusBalance;
    }

   /* (non-Javadoc)
 * @see ru.crystals.pos.api.card.Card#getCardStatus()
 */
    @Override
    public CardStatus getCardStatus() {
        return cardStatus;
    }
    
    /**
     * Установить статус данной карты/купона
     * @param status статус карты/купона
     * @see CardStatus
     */
    public void setCardStatus(CardStatus status) {
        this.cardStatus = status;
    }

    @Override
    public String toString() {
        return "CardEntity{" +
                "id='" + id + '\'' +
                ", cardNumber='" + cardNumber + '\'' +
                ", cardType=" + cardType +
                ", cardHolder=" + cardHolder +
                ", processingId='" + processingId + '\'' +
                ", bonusBalance=" + bonusBalance +
                ", cardStatus=" + cardStatus +
                '}';
    }
}
