package ru.crystals.pos.api.ext.loyal.dto;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import ru.crystals.pos.api.ext.loyal.dto.auxiliaries.LoyProviderFeedback;

/**
 * Резульатат обработки плагином события отмены расчета скидок.<br>
 * Такое событие возникает, например, если чек аннулируют или желают добавить товар после перехода к оплатам, но
 * до вноса первой оплаты.
 * @since 0.0.26
 */
public class DiscountCancellationResult {

    /**
     * Мапа расширенных атрибутов чека, которые плагин может к чеку прицепить.<br>
     * Необходима на случай, если вдруг плагинам нужно будет хранить какую-то исключительно свою информацию в чеке,
     * которая затем может выгружаться на стороне сервера в ERP или ещё зачем.
     */
    private Map<String, String> extendedAttributeMap;

    private List<LoyProviderFeedback> feedbacks;

    /**
     * Конструктор класса. Создаёт новый экземпляр класса {@link DiscountCancellationResult}.
     */
    public DiscountCancellationResult() {

    }

    /**
     * Мапа расширенных атрибутов, которыми плагин лояльности может наградить чек.<br>
     * Заполняется плагином в случае, если он хочет добавить к чеку какие-то дополнительные параметры.
     * @return мапу расширенных атрибутов чека или пустую мапу, если таких нет.
     */
    public Map<String, String> getExtendedReceiptAttributesMap() {
        if(extendedAttributeMap == null) {
            extendedAttributeMap = new HashMap<>();
        }
        return extendedAttributeMap;
    }

    /**
     * Получает список фидбеков, в который плагин может добавить свой.<br>
     * Полученный фидбек ставится в очередь на отложенную отправку.
     * При обработке фидбека, у плагина лояльности будет вызван метод {@link ru.crystals.pos.api.plugin.LoyaltyPlugin#onSendFeedback(LoyProviderFeedback)},
     * куда будет передан фидбек, добавленный в этот список.
     * @return список фидбеков, которые плагин образовал при обработке события отмены расчета скидок или пустой список, если фидбеков нет.
     */
    public List<LoyProviderFeedback> getFeedbacks() {
        if(feedbacks == null) {
            feedbacks = new ArrayList<>();
        }
        return feedbacks;
    }

    @Override
    public String toString() {
        return "DiscountCancellationResult{" +
                "extendedAttributeMap=" + extendedAttributeMap +
                ", feedbacks=" + feedbacks +
                '}';
    }
}
