package ru.crystals.pos.api.ext.loyal.dto.auxiliaries;

import ru.crystals.pos.spi.feedback.Feedback;

/**
 * Некий фидбэк, который плагину лояльности необходимо отправить в свой процессинг (ПЦ - Процессинговый Центр) по результатам расчета/применения скидок в чеке.
 *
 * @author aperevozchikov
 */
public class LoyProviderFeedback extends Feedback {

    /**
     * Количество уже совершенных попыток отправки данной информации в процессинговый центр.
     * <p>
     * NOTE: предполагается, что данное поле будет модифицировать сам плагин лояльности и, на основании достижения количества попыток
     * какого-либо порога, просто примет решение прекратить навсегда попытки отправить этот фидбэк в ПЦ.
     * Например, этот счетчик можно не менять, если произошла ошибка связи/соединения с ПЦ, и увеличивать при возникновении ошибок обработки
     * фидбэка в самом ПЦ.
     */
    private int attemptsCount = 0;

    /**
     * Стратегия сохранения фидбека, следует ли замещать им все старые, просто добавить новый, etc.
     * null соответствует стратегии {@link FeedbackSavingStrategy#REPLACE}.
     * @since 0.0.30
     */
    private FeedbackSavingStrategy savingStrategy = FeedbackSavingStrategy.REPLACE;

    public LoyProviderFeedback() {
        super(null);
    }

    /**
     * Вернет количество уже совершенных попыток отправки данной информации в процессинговый центр.
     *
     * @return число, что представляет меру "проблемности" (уже выясненной практическим путем) доставки данного feedback'а в процессинговый центр
     */
    public int getAttemptsCount() {
        return attemptsCount;
    }

    public void setAttemptsCount(int attemptsCount) {
        this.attemptsCount = attemptsCount;
    }

    /**
     * Возвращает стратегию сохранения данного фидбека: следует ли заместить им все старые (в рамках чека), просто добавить новый, etc.
     * null соответствует стратегии {@link FeedbackSavingStrategy#REPLACE}.
     * @return стратегия сохранения фидбека или null, что означает выбор стратегии по умолчанию.
     * @since 0.0.30
     */
    public FeedbackSavingStrategy getSavingStrategy() {
        return savingStrategy;
    }

    /**
     * Устанавливает стратегию сохранения данного фидбека.
     * @param savingStrategy стратегия сохранения фидбека
     * @since 0.0.30
     */
    public void setSavingStrategy(FeedbackSavingStrategy savingStrategy) {
        this.savingStrategy = savingStrategy;
    }

    @Override
    public String toString() {
        return "LoyProviderFeedback{" +
                "payload=" + getPayload() +
                ", attemptsCount=" + attemptsCount +
                ", savingStrategy=" + savingStrategy +
                '}';
    }
}
