package ru.crystals.pos.api.ext.loyal.dto.auxiliaries;

import java.util.HashMap;
import java.util.Map;
import ru.crystals.pos.api.ext.loyal.dto.BonusAccrualResult;
import ru.crystals.pos.api.ext.loyal.dto.Slip;

import java.util.ArrayList;
import java.util.List;

/**
 * Фидбек, возвращаемый плагином кассе при событии предфискализации
 * Может иметь слипы, которые будут распечатаны вместе с основым чеком
 * */
public class PreFiscalizationFeedback {

    /**
     * Список слипов добавленных плагином
     * */
    private List<Slip> slips;

    /**
     * Мапа транзакций начисления бонусных баллов на карту по результатам расчета лояльности.<br>
     * Ключом в мапе служит номер карты, на счет которой начислены бонусные баллы, значением - описание транзакции
     * начисления на карту бонусных баллов.
     */
    private Map<String, BonusAccrualResult> bonusAccrualResults;

    private List<LoyProviderFeedback> feedbacks;

    /**
     * Возвращает мапу транзакций начисления бонусных баллов на карту по результатам расчета лояльности.<br>
     * Ключом в мапе служит номер карты, на счет которой начислены бонусные баллы, значением - описание транзакции
     * начисления на карту бонусных баллов.
     * @return мапа транзакций начисления бонусных баллов или пустая мапа, если начислений не было
     */
    public Map<String, BonusAccrualResult> getBonusAccrualResults() {
        if(bonusAccrualResults == null) {
            bonusAccrualResults = new HashMap<>();
        }
        return bonusAccrualResults;
    }

    /**
     * Получить список слипов
     * @return никогда не вернет null. В крайнем случае пустой список.
     * */
    public List<Slip> getSlips() {
        if(slips == null) {
            slips = new ArrayList<>();
        }
        return slips;
    }

    /**
     * Получает список фидбеков, в который плагин может добавить свой.<br>
     * Полученный фидбек ставится в очередь на отложенную отправку.
     * При обработке фидбека, у плагина лояльности будет вызван метод {@link ru.crystals.pos.api.plugin.LoyaltyPlugin#onSendFeedback(LoyProviderFeedback)},
     * куда будет передан фидбек, добавленный в этот список.
     * @return список фидбеков, которые плагин образовал при обработке события предфискализации чека или пустой список, если фидбеков нет.
     * @since 0.0.26
     */
    public List<LoyProviderFeedback> getFeedbacks() {
        if(feedbacks == null) {
            feedbacks = new ArrayList<>();
        }
        return feedbacks;
    }

    @Override
    public String toString() {
        return "PreFiscalizationFeedback{" +
                "slips=" + slips +
                ", bonusAccrualResults=" + bonusAccrualResults +
                ", feedbacks=" + feedbacks +
                '}';
    }
}
