package ru.crystals.pos.api.plugin;

import java.math.BigDecimal;
import ru.crystals.pos.api.plugin.card.BonusOperationResponse;
import ru.crystals.pos.api.plugin.card.BonusOperationStatus;
import ru.crystals.pos.api.plugin.card.BonusWriteOffOperationResponse;
import ru.crystals.pos.api.plugin.card.CardInfo;
import ru.crystals.pos.api.plugin.card.CardSearchResponse;
import ru.crystals.pos.api.plugin.card.CardSearchResponseStatus;
import ru.crystals.pos.spi.plugin.card.CardSearchCallback;
import ru.crystals.pos.spi.plugin.card.CardSearchRequest;
import ru.crystals.pos.spi.receipt.Card;
import ru.crystals.pos.spi.receipt.Receipt;

/**
 * Интерфейс плагина карт (процессинга карт/купонов лояльности).
 *
 */
public interface CardPlugin {

    /**
     * Поиск информации по карте на основе предоставленных данных для поиска.
     *
     * @param request исходные данные для поиска карты
     * @return не {@code null}; при возникновении нештатных ситуаций следует возвращать объект с не-{@link CardSearchResponseStatus#OK позитивным}
     * {@link CardSearchResponse#getResponseStatus() статусом} обработки запроса
     */
    CardSearchResponse searchCard(CardSearchRequest request);

    /**
     * Выполняет поиск карты по номеру телефона.<br>
     * Метод асинхронный, использует каллбек для передачи резульата.
     * @param mobileNumber номер мобильного телефона, по которому необходимо найти карту.
     * @param callback калбек, который вызовется при завершении операции
     */
    void searchCardByMobileNumber(String mobileNumber, CardSearchCallback callback);

    /**
     * Списание бонусов с указанной карты.
     *
     * @param bonusCard бонусная карта, с баланса которой собираемся списать бонусы
     * @param bonusesToWriteOff количество бонусов для списания
     * @param receipt чек, в котором производится данное списание бонусов
     * @return не {@code null} - результат выполнения операции
     */
    default BonusWriteOffOperationResponse writeOff(Card bonusCard, BigDecimal bonusesToWriteOff, Receipt receipt) {
        return new BonusWriteOffOperationResponse(BonusOperationStatus.ERROR, null, null);
    }

    /**
     * Отмена списания бонусов.
     *
     * @param txId {@link BonusWriteOffOperationResponse#getTxId() идентификатор} транзакции списания бонусов, что надо "откатить"
     * @return не {@code null} - результат выполнения операции
     */
    default BonusOperationResponse rollback(String txId) {
        return new BonusOperationResponse(BonusOperationStatus.ERROR, null);
    }

    /**
     * Возвращает информацию о карте и его держателе.
     * @param request номер карты, по которой следует получить информацию.
     * @return информация о карте или иной результат, если карта не найдена.
     */
    default CardInfo getCardInfo(CardSearchRequest request) {
        return new CardInfo(CardSearchResponseStatus.UNKNOWN_CARD, null);
    }
}
