package ru.crystals.pos.api.receipt;

import java.util.Collections;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;
import ru.crystals.pos.spi.receipt.Card;
import ru.crystals.pos.spi.receipt.ExciseBottle;
import ru.crystals.pos.spi.receipt.LineItem;
import ru.crystals.pos.spi.receipt.Receipt;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import ru.crystals.pos.spi.receipt.ReceiptType;

/**
 * Реализует интерфейс {@link Receipt}, дополняя его сеттерами.
 */
public class ReceiptEntity implements Receipt, Serializable {
    private BigDecimal sumWihDiscount;
    private BigDecimal surchargeSum;
    private List<LineItem> lineItems;
    private int shiftNo;
    private int number;
    private List<Card> cards;
    private List<ExciseBottle> exciseBottles;
    private ReceiptType receiptType = ReceiptType.SALE;
    private Receipt saleReceipt;
    private Map<String, String> extendedAttributesMap;
    private Date dateCreate;
    /**
     * Конструктор класса. Создаёт новый экземпляр класса {@link ReceiptEntity}.
     */
    public ReceiptEntity() {
        // Должен иметь конструктор без аргументов потому что реализует Serializable
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public BigDecimal getSumWithDiscount() {
        return sumWihDiscount;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public BigDecimal getSurchargeSum() {
        return surchargeSum;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public List<LineItem> getLineItems() {
        return lineItems;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public int getShiftNo() {
        return shiftNo;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public int getNumber() {
        return number;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public Collection<Card> getCards() {
        if (cards == null) {
            cards = new ArrayList<>();
        }
        return cards;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public List<ExciseBottle> getExciseBottles() {
        if (exciseBottles == null) {
            exciseBottles = new ArrayList<>();
        }
        return exciseBottles;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public ReceiptType getType() {
        return receiptType;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public Receipt getSaleReceipt() {
        return saleReceipt;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public Map<String, String> getData() {
        if(extendedAttributesMap == null) {
            extendedAttributesMap = new HashMap<>();
        }
        return Collections.unmodifiableMap(extendedAttributesMap);
    }

    @Override
    public Date getDateCreate() {
        return dateCreate;
    }

    public void setSumWihDiscount(BigDecimal sumWihDiscount) {
        this.sumWihDiscount = sumWihDiscount;
    }

    public void setSurchargeSum(BigDecimal surchargeSum) {
        this.surchargeSum = surchargeSum;
    }

    public void setLineItems(List<LineItem> lineItems) {
        this.lineItems = lineItems;
    }

    public void setShiftNo(int shiftNo) {
        this.shiftNo = shiftNo;
    }

    public void setNumber(int number) {
        this.number = number;
    }

    public void setCards(List<Card> cards) {
        this.cards = cards;
    }

    public void setExciseBottles(List<ExciseBottle> exciseBottles) {
        this.exciseBottles = exciseBottles;
    }

    /**
     * Устанавливает тип чека.
     * @param receiptType тип чека
     */
    public void setReceiptType(ReceiptType receiptType) {
        this.receiptType = receiptType;
    }

    /**
     * Устанавливает оригинальный чек продажи, по которому осуществляется возврат.
     * @param saleReceipt чек продажи, для которого данный чек является чеком возврата.
     */
    public void setSaleReceipt(Receipt saleReceipt) {
        this.saleReceipt = saleReceipt;
    }

    public void setDateCreate(Date dateCreate) {
        this.dateCreate = dateCreate;
    }

    @Override
    public String toString() {
        return "ReceiptEntity{" +
                "sumWihDiscount=" + sumWihDiscount +
                ", surchargeSum=" + surchargeSum +
                ", lineItems=" + lineItems +
                ", shiftNo=" + shiftNo +
                ", number=" + number +
                ", cards=" + cards +
                ", exciseBottles=" + exciseBottles +
                ", receiptType=" + receiptType +
                ", saleReceipt=" + saleReceipt +
                ", extendedAttributesMap=" + extendedAttributesMap +
                ", dateCreate=" + dateCreate +
                '}';
    }
}
