package ru.crystals.pos.spi;

/**
 * Ошибка при обращении в некорректном состоянии.
 * <p>
 * Возникновение данной ошибки говорит о том, что произошло обращение к сервисам
 * кассы в неожиданный момент времени.
 * <h3>Пример возникновения исключения:</h3>
 * 
 * <pre>
 * &#064;POSPlugin(id = "foo.plugin")
 * public class FooPlugin implements PaymentPlugin {
 * 
 *     &#64;Inject
 *     private UIForms ui;
 * 
 *     &#64;Override
 *     public void doPayment(PaymentRequest request) {
 *         request.getPaymentCallback().paymentNotCompleted();
 * 
 *         // Следующая строка вызовет исключение IncorrectStateException
 *         // потому что взаимодействие с UIForms после завершения процесса
 *         // оплаты недопустимо.
 *         ui.showSpinnerForm("Message");
 *     }
 * 
 * }
 * </pre>
 */
public class IncorrectStateException extends Error {

    private static final long serialVersionUID = -8138835410650349529L;

}
