package ru.crystals.pos.spi.annotation;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Признак внедряемых (<i>dependency injection</i>) полей класса плагина.
 * <p>
 * Позволяет взаимодействовать с классами кассы.<br>
 * Внедрение работает только в классах имеющих аннотацию {@code @POSPlugin}<br>
 * Внедрение выполняется сразу после вызова конструктора класса.
 * 
 * <p>
 * Все классы и интерфейсы доступные для внедрения расширяют интерфейс
 * {@code Injectable}.<br>
 * Также для внедрения доступны все интерфейсы, которые можно получить в
 * {@linkplain ru.crystals.pos.spi.Facade Facade}.
 *
 * <h3>Пример:</h3>
 * 
 * <pre>
 * &#064;POSPlugin(id = "foo.plugin")
 * public class FooPlugin implements PaymentPlugin {
 * 
 *     &#064;Inject
 *     private POSInfo info; // для чтения основной информации о кассе
 * 
 * }
 * </pre>
 *
 * @see ru.crystals.pos.spi.Injectable
 * @see ru.crystals.pos.spi.annotation.POSPlugin
 *
 */
@Target(value = { ElementType.FIELD })
@Retention(value = RetentionPolicy.RUNTIME)
public @interface Inject {

}
