package ru.crystals.pos.spi.equipment;

import ru.crystals.pos.spi.Injectable;

/**
 * Дисплей покупателя.<br>
 * Это отдельное устройство, которое может быть подключено к кассе и отображать покупателю всякую интересную информацию: цены, наименования товаров, etc.
 * @since 0.0.19
 */
public interface CustomerDisplay extends Injectable {
    int E_INVALID = -1;
    /**
     * Устанавливает текст на дисплее покупателя. Используйте символ '\n' для переноса строк, однако обычно дисплеи покупателя поддерживают
     * не более двух строк.<br>
     * Следует также иметь в виду, что разные модели дисплея покупателя имеют различные ограничения на длину строк,
     * поэтому имеет смысл использовать сообщения возможно короче.
     * @param text текст, который необходимо установить на дисплее покупателя.
     */
    void setText(String text);

    /**
     * Получает число строк, которыми располагает текущий подключенный дисплей покупателя.
     * @return число строк, которыми располагает текущий подключенный дисплей покупателя или {@link #E_INVALID}, если устройство
     * не возвращает число своих строк.
     */
    int getRowsCount();

    /**
     * Получает число знакомест на строке, которыми располагает текущий подключенный дисплей покупателя.
     * @return число знакомест на строке, которыми располашает текущий подключенный дисплей покупателя или {@link #E_INVALID}, если
     * устройство не возвращает число знакомест на строке.
     */
    int getColumnsCount();
}
