package ru.crystals.pos.spi.ui.input;

import ru.crystals.pos.api.ui.listener.InputListener;
import ru.crystals.pos.api.ui.listener.InputScanNumberFormListener;
import ru.crystals.pos.api.ui.listener.ScanFormListener;
import ru.crystals.pos.spi.IncorrectStateException;
import ru.crystals.pos.spi.Injectable;

/**
 * Интерфейс для взаимодействия с пользовательским интерфейсом кассы.
 * Формы ввода данных. 
 */
public interface UIInputForms extends Injectable {

    /**
     * Показать форму для сканирования штрихкода.
     * 
     * @param caption
     *            заголовок формы
     * @param text
     *            текст формы
     * @param listener
     *            получатель событий формы
     * @throws IncorrectStateException
     *             если невозможно отобразить форму в данный момент
     */
    void showScanForm(String caption, String text, ScanFormListener listener) throws IncorrectStateException;

    /**
     * Показать форму для ввода номера.
     * 
     * @param caption
     *            заголовок формы
     * @param text
     *             текст формы
     * @param inputFieldHint
     *            текст в поле ввода номера
     * @param maxLength
     *            максимальное количество символов ввода
     * @param listener
     *            получатель событий формы
     * @throws IncorrectStateException
     *             если невозможно отобразить форму в данный момент
     */
    void showInputNumberForm(String caption, String text, String inputFieldHint, int maxLength, InputListener listener) throws IncorrectStateException;

    /**
     * Показать форму ввода шаблонизированного текста.<br>
     * Позволяет ввести текст в заранее заданный шаблон, подходит для ввода номеров телефонов по маске.
     * @param caption заголовок формы.
     * @param text текст формы
     * @param defaultValue предустановленное значение в поле ввода
     * @param inputHint текст-подсказка в поле ввода текста в случае, если в него не осуществлялся ввод
     * @param pattern шаблон, согласно которому фильтруются и форматируются вводимые символы.
     * <pre>{@code
     * # - цифра
     * L - буква
     * * - любой символ
     * 0-9 - число в заданном диапазоне
     * '13246' - неизменяемый текст обрамляется одиночными кавычками
     * Пример:
     * "+'7'(###)###-##-##" - шаблон для ввода номера телефона
     * }</pre>
     * @param listener слушатель событий формы
     * @throws IncorrectStateException если форму нельзя отобразить в настоящий момент.
     */
    void showPatternInputForm(String caption, String text, String defaultValue, String inputHint, String pattern, InputListener listener) throws IncorrectStateException;

    /**
     * Показать форму для ввода номера или сканирования.
     * 
     * @param caption
     *            заголовок формы
     * @param text
     *            текст формы
     * @param inputFieldHint
     *            текст в поле ввода номера
     * @param maxLength
     *            максимальное количество символов ввода
     * @param listener
     *            получатель событий формы
     * @throws IncorrectStateException
     *             если невозможно отобразить форму в данный момент
     */
    void showInputScanNumberForm(String caption, String text, String inputFieldHint, int maxLength, InputScanNumberFormListener listener) throws IncorrectStateException;

}
